import 'package:flutter_gb_authentication_basic/domain/entities/authentication_data.dart';
import 'package:flutter_gb_stack_base/flutter_gb_stack_base.dart';

class SessionExpiredFailure extends Failure {
  @override
  String? get code => 'SessionExpired';

  @override
  String? get message => "Current session has expired, try logging in again";
}

class NoAuthenticatedFailure extends Failure {
  @override
  String? get code => 'NoAuthenticatedFailure';

  @override
  String? get message => "Please make sure you are authenticated first.";
}

class NoParsableUserFailure extends Failure {
  final AuthenticationData partialData;

  NoParsableUserFailure({
    required this.partialData,
  });

  @override
  String? get code => "NoParsableUserFailure";

  @override
  String? get message => "The user information could't be correctly parsed";
}

class RefreshSessionFailure extends Failure {
  RefreshSessionFailure({
    Object? exception,
    String? refreshToken,
  }) {
    final UnknownFailure failure = UnknownFailure.fromException(exception);
    message = "Unable to refresh auth token\n";
    message += failure.message ?? "";
  }

  @override
  String? get code => "RefreshSessionFailure";

  @override
  late String message;
}
